summaryrefslogtreecommitdiff
path: root/gtk/packet_win.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk/packet_win.h')
-rw-r--r--gtk/packet_win.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/packet_win.h b/gtk/packet_win.h
index d018f588a5..ce42b10e57 100644
--- a/gtk/packet_win.h
+++ b/gtk/packet_win.h
@@ -41,7 +41,7 @@ extern void new_window_cb(GtkWidget *widget);
*/
void destroy_packet_wins(void);
-/** Redraw the hex dump panes of all packet windows. */
-void redraw_hex_dump_packet_wins(void);
+/** Redraw the packet bytes panes of all packet windows. */
+void redraw_packet_bytes_packet_wins(void);
#endif